<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>PC Speaker</source>
        <translation>Autofalante do computador</translation>
    </message>
</context>
<context>
    <name>PCSpeakerConfigurationWidget</name>
    <message>
        <source>Put the played sounds separate by space, _ for pause, eg. D2 C1# G0</source>
        <translation>Coloque os sons tocados separados por espaço, _ para pause, ex. D2 C1# G0</translation>
    </message>
</context>
</TS>